@@ -121,7 +121,7 @@ pub use wrapper::{QueryWrapper, UpdateWrapper, Wrapper};
 #[doc(inline)]
 pub use mapper::{BaseMapper, IPage, AkitaMapper};
 #[doc(inline)]
-pub use segment::SqlSegment;
+pub use segment::{SqlSegment, Segment, AkitaKeyword};
 #[doc(inline)]
 pub use errors::AkitaError;
 #[doc(inline)]
